@@ -2,6 +2,7 @@ from myst.connectors.model_connectors.elastic_net import ElasticNet
 from myst.connectors.model_connectors.extra_trees_regression import ExtraTreesRegression
 from myst.connectors.model_connectors.lightgbm import LightGBM
 from myst.connectors.model_connectors.linear_regression import LinearRegression
+from myst.connectors.model_connectors.logistic_regression import LogisticRegression
 from myst.connectors.model_connectors.mlp_regression import MLPRegression
 from myst.connectors.model_connectors.ngboost import NGBoost
 from myst.connectors.model_connectors.random_forest_regression import RandomForestRegression
@@ -12,6 +13,7 @@ __all__ = [
     "ExtraTreesRegression",
     "LightGBM",
     "LinearRegression",
+    "LogisticRegression",
     "MLPRegression",
     "NGBoost",
     "RandomForestRegression",
