@@ -1,7 +1,6 @@
 import enum
 from dataclasses import dataclass
-from typing import List
-from typing import Optional
+from typing import List, Optional
 from uuid import UUID
 
 from myst.connectors.source_connector import SourceConnector
