@@ -3,7 +3,7 @@ from myst.openapi.models.model_fit_job_get import ModelFitJobGet
 
 
 def request_sync(client: Client, project_uuid: str, model_uuid: str, uuid: str) -> ModelFitJobGet:
-    """Get a fit job for model."""
+    """Gets a model fit job by its unique identifier."""
 
     return client.request(
         method="get",
