@@ -15,12 +15,12 @@ def request_sync(
 ) -> TimeSeriesQueryResultGet:
     """Queries time series data."""
 
-    params: Dict[str, Any] = {
-        "start_time": start_time,
-        "end_time": end_time,
-        "as_of_time": as_of_time,
-        "as_of_offset": as_of_offset,
-    }
+    params: Dict[str, Any] = {}
+    params["start_time"] = start_time
+    params["end_time"] = end_time
+    params["as_of_time"] = as_of_time
+    params["as_of_offset"] = as_of_offset
+
     params = {k: v for k, v in params.items() if v is not None}
 
     return client.request(
