@@ -1,9 +1,10 @@
-from typing import Dict, Optional
+from typing import Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.backtest_result_get_metrics import BacktestResultGetMetrics
 
 
 class BacktestResultGet(base_model.BaseModel):
@@ -15,4 +16,4 @@ class BacktestResultGet(base_model.BaseModel):
     start_time: str
     end_time: str
     result_url: str
-    metrics: Optional[Dict[str, Optional[float]]] = None
+    metrics: Optional[BacktestResultGetMetrics] = None
