@@ -1,19 +1,14 @@
-from typing import Dict, Optional, Union
+from typing import Optional, Union
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
 from myst.openapi.models.absolute_timing_get import AbsoluteTimingGet
-from myst.openapi.models.choice import Choice
-from myst.openapi.models.constant import Constant
 from myst.openapi.models.cron_timing_get import CronTimingGet
 from myst.openapi.models.hyperopt_get import HyperoptGet
-from myst.openapi.models.log_uniform import LogUniform
-from myst.openapi.models.q_log_uniform import QLogUniform
-from myst.openapi.models.q_uniform import QUniform
 from myst.openapi.models.relative_timing_get import RelativeTimingGet
-from myst.openapi.models.uniform import Uniform
+from myst.openapi.models.search_space import SearchSpace
 
 
 class HPOGet(base_model.BaseModel):
@@ -26,7 +21,7 @@ class HPOGet(base_model.BaseModel):
     project: str
     model: str
     creator: str
-    search_space: Dict[str, Optional[Union[Uniform, QUniform, LogUniform, QLogUniform, Choice, Constant]]]
+    search_space: SearchSpace
     search_algorithm: HyperoptGet
     fit_start_timing: Union[AbsoluteTimingGet, RelativeTimingGet]
     fit_end_timing: Union[AbsoluteTimingGet, RelativeTimingGet]
