@@ -6,7 +6,7 @@ from myst.models import base_model
 class HPOTrialMetrics(base_model.BaseModel):
     """"""
 
-    __root__: Dict[str, Any]
+    __root__: Dict[str, float]
 
     def __getitem__(self, item: str) -> Any:
         return self.__root__[item]
