@@ -4,7 +4,6 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-from myst.openapi.models.model_fit_result_get_inputs import ModelFitResultGetInputs
 
 
 class ModelFitResultGet(base_model.BaseModel):
@@ -19,5 +18,5 @@ class ModelFitResultGet(base_model.BaseModel):
     end_time: str
     as_of_time: str
     fit_state_url: str
-    inputs: ModelFitResultGetInputs
+    inputs_url: str
     update_time: Optional[str] = None
