@@ -1,12 +1,11 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.model_run_result_get import ModelRunResultGet
+from myst.openapi.models.model_run_result_list_item import ModelRunResultListItem
 
 
 class ModelRunResultList(base_model.BaseModel):
     """Schema for model run result list responses."""
 
-    data: List[ModelRunResultGet]
+    data: List[ModelRunResultListItem]
     has_more: bool
