@@ -4,7 +4,7 @@ from myst.models import base_model
 
 
 class OperationUpdateInputSpecsSchema(base_model.BaseModel):
-    """A JSON Schema definition describing the inputs that this operation can be used with."""
+    """**Ignored**. A JSON Schema definition describing the inputs that this operation can be used with. Output only."""
 
     __root__: Dict[str, Any]
 
