@@ -10,7 +10,7 @@ from myst.openapi.models.uniform import Uniform
 
 
 class SearchSpace(base_model.BaseModel):
-    """"""
+    """Represents a search space, or a mapping from parameters to sampling functions."""
 
     __root__: Dict[str, Union[Choice, Constant, LogUniform, QLogUniform, QUniform, Uniform]]
 
