@@ -1,10 +1,11 @@
-from typing import Any, Dict, List, Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
 from myst.openapi.models.deploy_status import DeployStatus
+from myst.openapi.models.source_update_parameters import SourceUpdateParameters
 from myst.openapi.models.time_dataset_spec import TimeDatasetSpec
 
 
@@ -23,5 +24,5 @@ class SourceUpdate(base_model.BaseModel):
     project: Optional[str] = None
     deploy_status: Optional[DeployStatus] = None
     connector_uuid: Optional[str] = None
-    parameters: Optional[Dict[str, Any]] = None
+    parameters: Optional[SourceUpdateParameters] = None
     output_specs: Optional[List[TimeDatasetSpec]] = None
