@@ -135,8 +135,8 @@ class Model(ConnectorNode):
     def create_fit_policy(
         self,
         schedule_timing: Union[Time, TimeDelta, ScheduleTiming],
-        start_timing: Optional[TimeRangeBoundary] = None,
-        end_timing: Optional[TimeRangeBoundary] = None,
+        start_timing: TimeRangeBoundary,
+        end_timing: TimeRangeBoundary,
         active: bool = True,
     ) -> ModelFitPolicy:
         return ModelFitPolicy.create(
