@@ -9,7 +9,7 @@ from myst.connectors.source_connector import SourceConnector
 from myst.core.time.time_delta import TimeDelta
 from myst.models.enums import DeployStatus, OrgSharingRole
 from myst.models.types import UNSET, AxisLabels, CoordinateLabels, OptionalArgument, Shape, UUIDOrStr, to_uuid
-from myst.openapi.api.projects import create_project, get_project, list_projects, update_project
+from myst.openapi.api.projects import create_project, delete_project, get_project, list_projects, update_project
 from myst.openapi.api.projects.edges import list_project_edges
 from myst.openapi.api.projects.nodes import list_project_nodes
 from myst.openapi.models.input_get import InputGet
@@ -167,6 +167,42 @@ class Project(ShareableResource):
 
         return Project.parse_obj(project)
 
+    def delete(self, requires_confirmation: bool = True) -> "Project":
+        """Deletes the project.
+
+        Args:
+            requires_confirmation: whether or not the user is required to confirm the project title
+
+        Raises:
+            ValueError: if confirmation input title is not matched
+
+        Returns:
+            project that has been deleted
+        """
+        if requires_confirmation:
+            title = input("Please input the project title to continue:")
+
+            if title != self.title:
+                raise ValueError("Input title is not matching the project title.")
+
+        project = delete_project.request_sync(client=get_client(), uuid=str(self.uuid))
+
+        return Project.parse_obj(project)
+
+    @classmethod
+    def filter(cls, title: str) -> List["Project"]:
+        """Filters all projects visible to the user by title.
+
+        Args:
+            title: the title of the project to filter
+
+        Returns:
+            list of projects that have the specified title
+        """
+        projects = [project for project in cls.list() if project.title == title]
+
+        return projects
+
     def list_nodes(self) -> List[Node]:
         """Lists all nodes in this project."""
         project_nodes = list_project_nodes.request_sync(client=get_client(), project_uuid=str(self.uuid))
