@@ -13,6 +13,7 @@ import pandas as pd
 from myst.adapters.utils import get_resource_uuid
 from myst.client import get_client
 from myst.core.time.time import Time
+from myst.models.base_model import BaseModel
 from myst.models.time_dataset import TimeDataset
 from myst.models.types import UUIDOrStr
 from myst.openapi.api.projects.models.fit_results import get_model_fit_result, list_model_fit_results
@@ -31,6 +32,7 @@ TENSORBOARD_FIT_STATE_KEY = "tensorboard_logs_base64"
 
 class NodeResult(Resource):
     """Describes a result associated with a node.
+
     Attributes:
         project: the UUID of the project this result corresponds to
         node: the UUID of the node this result corresponds to
@@ -46,12 +48,25 @@ class NodeResult(Resource):
     as_of_time: Time
 
 
+Inputs = Dict[str, List[TimeDataset]]
+
+
+class InputsEnvelope(BaseModel):
+    """The data that was used to calculate the fit result."""
+
+    object: str
+    inputs: Dict[str, List[TimeDataset]]
+
+
 class ModelFitResult(NodeResult):
     """Results from a single run of a model fit.
+
     Attributes:
-        fit_state_url: an external URL to the model fit state blob
+        inputs_url: an authenticated, time-expiring URL to the inputs used to create the fit result
+        fit_state_url: an authenticated, time-expiring URL to the raw model fit state
     """
 
+    inputs_url: Optional[str]
     fit_state_url: Optional[str]
 
     @classmethod
@@ -80,14 +95,31 @@ class ModelFitResult(NodeResult):
             for model_fit_result in model_fit_results.data
         ]
 
+    def _refresh(self) -> None:
+        model_fit_result_detailed = get_model_fit_result.request_sync(
+            client=get_client(), project_uuid=str(self.project), model_uuid=str(self.node), uuid=str(self.uuid)
+        )
+        self.inputs_url = model_fit_result_detailed.inputs_url
+        self.fit_state_url = model_fit_result_detailed.fit_state_url
+
+    def download_inputs(self) -> Dict[str, Any]:
+        """Downloads the inputs that were used to generate the model fit result."""
+        # Lazy load the inputs URL, for example if this object was acquired through a list rather than a get.
+        if self.inputs_url is None:
+            self._refresh()
+
+        response = httpx.get(self.inputs_url)
+
+        if response.status_code == 200:
+            return InputsEnvelope.parse_raw(response.content).inputs
+        else:
+            raise RuntimeError("Could not download inputs.")
+
     def download_fit_state(self) -> Dict[str, Any]:
-        """Downloads the fit state from the supplied URL and parses it."""
+        """Downloads the fit state and parses it."""
         # Lazy load the fit state URL, for example if this object was acquired through a list rather than a get.
         if self.fit_state_url is None:
-            model_fit_result_detailed = get_model_fit_result.request_sync(
-                client=get_client(), project_uuid=str(self.project), model_uuid=str(self.node), uuid=str(self.uuid)
-            )
-            self.fit_state_url = model_fit_result_detailed.fit_state_url
+            self._refresh()
 
         response = httpx.get(self.fit_state_url)
 
